@@ -16,6 +16,8 @@
 import octobot_tentacles_manager.api as tentacles_manager_api
 import octobot.constants as constants
 import octobot_commons.databases as databases
+import octobot_commons.logging as logging
+import octobot_commons.errors as commons_errors
 import octobot.databases_util as databases_util
 
 
@@ -34,15 +36,23 @@ class Initializer:
         self.octobot.tentacles_setup_config = tentacles_manager_api.get_tentacles_setup_config(tentacles_config_path)
 
         if init_bot_storage:
-            # init bot storage
-            await databases.init_bot_storage(
-                self.octobot.bot_id,
-                databases_util.get_run_databases_identifier(
-                    self.octobot.config,
-                    self.octobot.tentacles_setup_config
-                ),
-                True
-            )
+            try:
+                # init bot storage
+                await databases.init_bot_storage(
+                    self.octobot.bot_id,
+                    databases_util.get_run_databases_identifier(
+                        self.octobot.config,
+                        self.octobot.tentacles_setup_config
+                    ),
+                    True
+                )
+            except commons_errors.ConfigTradingError as err:
+                # already logged as error, don't display it twice
+                logging.get_logger(self.__class__.__name__).warning(f"Error when initializing bot storage: {err}")
+            except Exception as err:
+                logging.get_logger(self.__class__.__name__).exception(
+                    err, True, f"Error when initializing bot storage: {err}"
+                )
 
         # create OctoBot channel
         await self.octobot.global_consumer.initialize()
